@@ -28,9 +28,6 @@ class InternalBackendConf(SharedBackendConfUtils):
     def numH2OWorkers(self):
         return self._get_option(self._jconf.numH2OWorkers())
 
-    def extraClusterNodes(self):
-        return self._jconf.extraClusterNodes()
-
     def drddMulFactor(self):
         return self._jconf.drddMulFactor()
 
@@ -49,54 +46,42 @@ class InternalBackendConf(SharedBackendConfUtils):
     def spreadRddRetriesTimeout(self):
         return self._jconf.spreadRddRetriesTimeout()
 
-    def isDirectIpConfigurationEnabled(self):
-        return self._jconf.isDirectIpConfigurationEnabled()
+    def nodeIcedDir(self):
+        return self._get_option(self._jconf.nodeIcedDir())
 
 
     #
     # Setters
     #
 
-    def setNumH2OWorkers(self, arg0):
-        self._jconf.setNumH2OWorkers(arg0)
+    def setNumH2OWorkers(self, value):
+        self._jconf.setNumH2OWorkers(value)
         return self
 
-    def setExtraClusterNodesEnabled(self):
-        self._jconf.setExtraClusterNodesEnabled()
+    def setDrddMulFactor(self, value):
+        self._jconf.setDrddMulFactor(value)
         return self
 
-    def setExtraClusterNodesDisabled(self):
-        self._jconf.setExtraClusterNodesDisabled()
+    def setNumRddRetries(self, value):
+        self._jconf.setNumRddRetries(value)
         return self
 
-    def setDrddMulFactor(self, arg0):
-        self._jconf.setDrddMulFactor(arg0)
+    def setDefaultCloudSize(self, value):
+        self._jconf.setDefaultCloudSize(value)
         return self
 
-    def setNumRddRetries(self, arg0):
-        self._jconf.setNumRddRetries(arg0)
+    def setSubseqTries(self, value):
+        self._jconf.setSubseqTries(value)
         return self
 
-    def setDefaultCloudSize(self, arg0):
-        self._jconf.setDefaultCloudSize(arg0)
+    def setHdfsConf(self, value):
+        self._jconf.setHdfsConf(value)
         return self
 
-    def setSubseqTries(self, arg0):
-        self._jconf.setSubseqTries(arg0)
+    def setSpreadRddRetriesTimeout(self, value):
+        self._jconf.setSpreadRddRetriesTimeout(value)
         return self
 
-    def setHdfsConf(self, *args):
-        self._jconf.setHdfsConf(*args)
-        return self
-
-    def setSpreadRddRetriesTimeout(self, arg0):
-        self._jconf.setSpreadRddRetriesTimeout(arg0)
-        return self
-
-    def setDirectIpConfigurationEnabled(self):
-        self._jconf.setDirectIpConfigurationEnabled()
-        return self
-
-    def setDirectIpConfigurationDisabled(self):
-        self._jconf.setDirectIpConfigurationDisabled()
+    def setNodeIcedDir(self, value):
+        self._jconf.setNodeIcedDir(value)
         return self
