@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OGBM import H2OGBM
 
@@ -30,10 +30,9 @@ class H2OGBMClassifier(H2OGBM):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
                  detailedPredictionCol="detailed_prediction",
                  validationDataFrame=None,
@@ -42,13 +41,13 @@ class H2OGBMClassifier(H2OGBM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  learnRate=0.1,
                  learnRateAnnealing=1.0,
                  sampleRate=1.0,
                  colSampleRate=1.0,
                  maxAbsLeafnodePred=1.7976931348623157E308,
                  predNoiseBandwidth=0.0,
-                 interactionConstraints=None,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
@@ -68,10 +67,7 @@ class H2OGBMClassifier(H2OGBM):
                  minSplitImprovement=1.0E-5,
                  histogramType="AUTO",
                  calibrateModel=False,
-                 calibrationMethod="AUTO",
                  checkConstantResponse=True,
-                 inTrainingCheckpointsDir=None,
-                 inTrainingCheckpointsTreeInterval=1,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -96,14 +92,12 @@ class H2OGBMClassifier(H2OGBM):
                  gainsliftBins=-1,
                  customMetricFunc=None,
                  customDistributionFunc=None,
-                 exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OGBM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OGBMClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
