@@ -30,9 +30,7 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -82,9 +80,8 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  skipDrop=0.0,
                  dmatrixType="auto",
                  backend="auto",
-                 gpuId=None,
+                 gpuId=0,
                  interactionConstraints=None,
-                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -105,14 +102,12 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
-                 exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OXGBoost, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OXGBoostClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
