@@ -37,34 +37,17 @@ class H2OTargetEncoder(H2OTargetEncoderMOJOParams, H2OStageBase, JavaEstimator):
                  blendedAvgInflectionPoint=10.0,
                  blendedAvgSmoothing=20.0,
                  noise=0.01,
-                 noiseSeed=-1,
-                 columnsToEncode=None,
-                 problemType="Auto"):
+                 noiseSeed=-1):
         Initializer.load_sparkling_jar()
         super(H2OTargetEncoder, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.features.H2OTargetEncoder", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        if 'inputCols' in kwargs:
-            kwargs['inputCols'] = self._convertInputCols(kwargs['inputCols'])
         self._set(**kwargs)
-        self.setInputCols(self.getInputCols())
 
     def _create_model(self, java_model):
         return H2OTargetEncoderModel(java_model)
 
-    def _toStringArray(self, value):
-        if isinstance(value, list):
-            return value
-        else:
-            return [str(value)]
-
-    def _convertInputCols(self, value):
-        if isinstance(value, list):
-            return [self._toStringArray(item) for item in value]
-        else:
-            return value
-
     ##
     # Setters
     ##
@@ -75,7 +58,7 @@ class H2OTargetEncoder(H2OTargetEncoderMOJOParams, H2OStageBase, JavaEstimator):
         return self._set(labelCol=value)
 
     def setInputCols(self, value):
-        return self._set(inputCols=self._convertInputCols(value))
+        return self._set(inputCols=value)
 
     def setOutputCols(self, value):
         return self._set(outputCols=value)
@@ -97,6 +80,3 @@ class H2OTargetEncoder(H2OTargetEncoderMOJOParams, H2OStageBase, JavaEstimator):
 
     def setNoiseSeed(self, value):
         return self._set(noiseSeed=value)
-
-    def setProblemType(self, value):
-        return self._set(problemType=value)
