@@ -271,8 +271,3 @@ class H2OGBMMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneConstrai
     def getExportCheckpointsDir(self):
         value = self._java_obj.getExportCheckpointsDir()
         return value
-
-
-    def getAucType(self):
-        value = self._java_obj.getAucType()
-        return value
