@@ -258,8 +258,8 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     gpuId = Param(
         Params._dummy(),
         "gpuId",
-        """Which GPU(s) to use. """,
-        H2OTypeConverters.toNullableListInt())
+        """Which GPU to use. """,
+        H2OTypeConverters.toInt())
 
     interactionConstraints = Param(
         Params._dummy(),
@@ -267,12 +267,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """A set of allowed column interactions.""",
         H2OTypeConverters.toNullableListListString())
 
-    scalePosWeight = Param(
-        Params._dummy(),
-        "scalePosWeight",
-        """Controls the effect of observations with positive labels in relation to the observations with negative labels on gradient calculation. Useful for imbalanced problems.""",
-        H2OTypeConverters.toFloat())
-
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -324,7 +318,7 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -399,12 +393,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
-    aucType = Param(
-        Params._dummy(),
-        "aucType",
-        """Set default multinomial AUC type.""",
-        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
-
     ##
     # Getters
     ##
@@ -528,9 +516,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getInteractionConstraints(self):
         return self.getOrDefault(self.interactionConstraints)
 
-    def getScalePosWeight(self):
-        return self.getOrDefault(self.scalePosWeight)
-
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -594,9 +579,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
-    def getAucType(self):
-        return self.getOrDefault(self.aucType)
-
     ##
     # Setters
     ##
@@ -720,9 +702,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setInteractionConstraints(self, value):
         return self._set(interactionConstraints=value)
 
-    def setScalePosWeight(self, value):
-        return self._set(scalePosWeight=value)
-
     def setModelId(self, value):
         return self._set(modelId=value)
 
@@ -785,6 +764,3 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
-
-    def setAucType(self, value):
-        return self._set(aucType=value)
